aboutsummaryrefslogtreecommitdiffstats
path: root/engine/pokemon/load_mon_data.asm
diff options
context:
space:
mode:
Diffstat (limited to 'engine/pokemon/load_mon_data.asm')
-rw-r--r--engine/pokemon/load_mon_data.asm10
1 files changed, 5 insertions, 5 deletions
diff --git a/engine/pokemon/load_mon_data.asm b/engine/pokemon/load_mon_data.asm
index 3d9417a7..964db2e4 100644
--- a/engine/pokemon/load_mon_data.asm
+++ b/engine/pokemon/load_mon_data.asm
@@ -4,11 +4,11 @@ LoadMonData_::
; 1: enemymon
; 2: boxmon
; 3: daycaremon
; Return monster id at wcf91 and its data at wLoadedMon.
; Also load base stats at wMonHeader for convenience.
ld a, [wDayCareMonSpecies]
- ld [wcf91], a
+ ld [wCurPartySpecies], a
ld a, [wMonDataLocation]
cp DAYCARE_DATA
jr z, .GetMonHeader
@@ -18,8 +18,8 @@ LoadMonData_::
call GetMonSpecies
.GetMonHeader
- ld a, [wcf91]
- ld [wd0b5], a ; input for GetMonHeader
+ ld a, [wCurPartySpecies]
+ ld [wCurSpecies], a
call GetMonHeader
ld hl, wPartyMons
@@ -64,5 +64,5 @@ GetMonSpecies:
ld d, 0
add hl, de
ld a, [hl]
- ld [wcf91], a
+ ld [wCurPartySpecies], a
ret
@@ -4,11 +4,11 @@ LoadMonData_::
; 2: boxmon
; 3: daycaremon
-; Return monster id at wcf91 and its data at wLoadedMon.
+; Return monster id at wCurPartySpecies and its data at wLoadedMon.
; Also load base stats at wMonHeader for convenience.
ld a, [wDayCareMonSpecies]